Class: Mutant::Matcher::Method Private

Inherits:
Mutant::Matcher show all
Includes:
Unparser::AbstractType, Unparser::Adamantium
Defined in:
lib/mutant/matcher/method.rb,
lib/mutant/matcher/method/instance.rb,
lib/mutant/matcher/method/metaclass.rb,
lib/mutant/matcher/method/singleton.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Abstract base class for method matchers

API:

  • private

Direct Known Subclasses

Instance, Metaclass, Singleton

Defined Under Namespace

Classes: Evaluator, Instance, Metaclass, Singleton

Constant Summary collapse

SOURCE_LOCATION_WARNING_FORMAT =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

API:

  • private

'%s does not have a valid source location, unable to emit subject'
CLOSURE_WARNING_FORMAT =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

API:

  • private

'%s is dynamically defined in a closure, unable to emit subject'
CONSTANT_SCOPES =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

API:

  • private

{
  class:  Context::ConstantScope::Class,
  module: Context::ConstantScope::Module
}.freeze

Instance Method Summary collapse

Methods inherited from Mutant::Matcher

expand

Instance Method Details

#call(env) ⇒ Enumerable<Subject>

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Matched subjects

Parameters:

Returns:

API:

  • private



27
28
29
# File 'lib/mutant/matcher/method.rb', line 27

def call(env)
  evaluator.call(scope:, target_method:, env:)
end