Module: Mutant::Reporter::CLI::Printer::AliveResults Private
- Included in:
- CLI::Command::Session::Show, CLI::Command::Session::Subject
- Defined in:
- lib/mutant/reporter/cli/printer/alive_results.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
Shared logic for printing alive mutation results
Constant Summary collapse
- ALIVE_EXPLANATION =
This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.
<<~'MESSAGE' Uncovered mutations detected, exiting nonzero! Alive mutations require one of two actions: A) Keep the mutated code: Your tests specify the correct semantics, and the original code is redundant. Accept the mutation. B) Add a missing test: The original code is correct, but the tests do not verify the behavior the mutation removed. MESSAGE
Instance Method Summary collapse
Instance Method Details
#print_alive_results(failed_subject_results) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
18 19 20 21 22 |
# File 'lib/mutant/reporter/cli/printer/alive_results.rb', line 18 def print_alive_results(failed_subject_results) failed_subject_results.each do |subject_result| SubjectResult.call(display_config:, output:, object: subject_result) end end |