Class: Mutant::Usage::Opensource Private

Inherits:
Mutant::Usage show all
Defined in:
lib/mutant/usage.rb

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Constant Summary collapse

VALUE =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

'opensource'
MESSAGE =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

"## Opensource use\n\n`opensource` usage is free while mutant is run on an opensource project.\nUnder that usage mutant does not require any kind of sign up or payment.\nSet this usage type exclusively on public opensource projects. Any other\nscenario requires payment.\nUsing the `opensource` usage type on private repotiories and or on commercial\ncode bases is not valid.\n\nTo use `opensource` usage type either specify `--usage opensource` on the command\nline or use the config file key `usage`:\n\n```\n# mutant.yml or config/mutant.yml\nusage: opensource\n```\n"

Constants inherited from Mutant::Usage

CLI_REGEXP, TRANSFORM

Method Summary

Methods inherited from Mutant::Usage

#merge, #message, parse, #value, #verify