Class: Mutant::Mutator::Node::Send::Binary Private
- Inherits:
-
Mutant::Mutator::Node::Send
- Object
- Mutant::Mutator
- Mutant::Mutator::Node
- Mutant::Mutator::Node::Send
- Mutant::Mutator::Node::Send::Binary
- Defined in:
- lib/mutant/mutator/node/send/binary.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Mutator for sends that correspond to a binary operator
Constant Summary collapse
- MULTIPLICATION_DIVISION_SWAP =
This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.
Pairs of operators where swapping produces equivalent mutants when the right operand is a multiplicative identity (1 or -1).
{ %i[* /].freeze => true, %i[/ *].freeze => true }.freeze
Constants inherited from Mutant::Mutator::Node::Send
RECEIVER_SELECTOR_REPLACEMENTS, REGEXP_END_WITH_NODES, REGEXP_MATCH_METHODS, REGEXP_START_WITH_NODES
Constants included from AST::Types
AST::Types::ALL, AST::Types::ASSIGNABLE_VARIABLES, AST::Types::BINARY_METHOD_OPERATORS, AST::Types::BLACKLIST, AST::Types::GENERATED, AST::Types::INDEX_OPERATORS, AST::Types::METHOD_OPERATORS, AST::Types::NOT_STANDALONE, AST::Types::OP_ASSIGN, AST::Types::UNARY_METHOD_OPERATORS
Constants inherited from Mutant::Mutator::Node
Constants included from AST::Nodes
AST::Nodes::N_EMPTY, AST::Nodes::N_EMPTY_ARRAY, AST::Nodes::N_EMPTY_HASH, AST::Nodes::N_EMPTY_STRING, AST::Nodes::N_EMPTY_SUPER, AST::Nodes::N_FALSE, AST::Nodes::N_INFINITY, AST::Nodes::N_NAN, AST::Nodes::N_NEGATIVE_INFINITY, AST::Nodes::N_NIL, AST::Nodes::N_RAISE, AST::Nodes::N_SELF, AST::Nodes::N_TRUE, AST::Nodes::N_ZERO_FLOAT, AST::Nodes::N_ZERO_INTEGER, AST::Nodes::N_ZSUPER